@@ -66,7 +66,8 @@ def jobs(token, location):
 def get_token(token) -> str:
     if not token:
         if "DB_TOKEN" not in os.environ:
-            print("Expected a Databricks token to be set as a environment variable named 'DB_TOKEN'")
+            print("Expected a Databricks token to be set as a environment variable named 'DB_TOKEN' or "
+                  "passed in as an option '--token'.")
             sys.exit(1)
         return os.environ.get("DB_TOKEN")
 
